@@ -4,8 +4,8 @@ use 5.010001;
 use strict;
 use warnings;
 
-our $VERSION = '0.30'; # VERSION
-our $DATE = '2014-11-28'; # DATE
+our $VERSION = '0.31'; # VERSION
+our $DATE = '2014-12-03'; # DATE
 
 our $_complete_module = sub {
     require Complete::Module;
@@ -72,35 +72,12 @@ App::PMUtils - Command-line utilities related to Perl modules
 
 =head1 VERSION
 
-This document describes version 0.30 of App::PMUtils (from Perl distribution App-PMUtils), released on 2014-11-28.
+This document describes version 0.31 of App::PMUtils (from Perl distribution App-PMUtils), released on 2014-12-03.
 
 =head1 SYNOPSIS
 
-This distribution provides the following command-line utilities:
-
- pmbin
- pmcore
- pmcost
- pmdoc
- pmedit
- pminfo
- pmless
- pmlist
- pmman
- pmpath
- pmuninst
- pmversion
- podpath
-
-These utilities have tab completion capability. To activate it, put these lines
-to your bash startup file (e.g. C</etc/bash.bashrc>, C<~/.bash_profile>, or
-C<~/.bashrc>):
-
- for p in \
-   pmbin pmcore pmcost pmdoc pmedit pminfo pmless pmlist pmman pmpath \
-   pmuninst pmversion podpath; do
-     complete -C $p $p
- done
+This distribution provides several command-line utilities related to Perl
+modules. The main purpose of these utilities is tab completion.
 
 =head1 FAQ
 
@@ -110,12 +87,9 @@ For example, L<mpath> in L<Module::Path> distribution, L<mversion> in
 L<Module::Version> distribution, etc.
 
 True. The main point of these utilities is shell tab completion, to save
-typing.
+typing. For example,
 
-=head2 In shell completion, why do you use / (slash) instead of :: (double colon) as it should be?
-
-If you type module name which doesn't contain any ::, / will be used as
-namespace separator. Otherwise if you already type ::, it will use ::.
+=head2 For shell completion, why do you recommend the use of / (slash) instead of :: (double colon) as it should be?
 
 Colon is problematic because by default it is a word breaking character in bash.
 This means, in this command:
@@ -133,7 +107,11 @@ The solution is to use quotes, e.g.
  % pmpath "Text:<tab>
  % pmpath 'Text:<tab>
 
-or, use /.
+or, use /, which is by default not a word-breaking character in bash.
+
+The utilities are a bit smart: they accept both kinds of separator. If you type
+module name which doesn't contain any ::, / will be used as namespace separator;
+otherwise if you already type ::, it will use :: as the separator.
 
 =head1 SEE ALSO
 
@@ -147,7 +125,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/App-PMUtil
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-App-PMUtils>.
+Source repository is at L<https://github.com/perlancar/perl-App-PMUtils>.
 
 =head1 BUGS
 
